@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 
 	"go.mongodb.org/mongo-driver/bson"
@@ -23,12 +24,12 @@ import (
 
 // CollectionStatsHandler
 // https://docs.mongodb.com/manual/reference/command/collStats/index.html
-func CollectionStatsHandler(s Session, params map[string]string) (interface{}, error) {
+func CollectionStatsHandler(ctx context.Context, s Session, params map[string]string) (any, error) {
 	colStats := &bson.M{}
 	err := s.DB(params["Database"]).Run(
+		ctx,
 		&bson.D{
 			{Key: "collStats", Value: params["Collection"]},
-			{Key: "maxTimeMS", Value: s.GetMaxTimeMS()},
 		}, colStats,
 	)
 
