@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 	"sort"
 
@@ -28,8 +29,8 @@ type colEntity struct {
 
 // CollectionsDiscoveryHandler
 // https://docs.mongodb.com/manual/reference/command/listDatabases/
-func CollectionsDiscoveryHandler(s Session, _ map[string]string) (interface{}, error) {
-	dbs, err := s.DatabaseNames()
+func CollectionsDiscoveryHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
+	dbs, err := s.DatabaseNames(ctx)
 	if err != nil {
 		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
 	}
@@ -39,7 +40,8 @@ func CollectionsDiscoveryHandler(s Session, _ map[string]string) (interface{}, e
 	lld := make([]colEntity, 0)
 
 	for _, db := range dbs {
-		collections, err := s.DB(db).CollectionNames()
+		var collections []string
+		collections, err = s.DB(db).CollectionNames(ctx)
 
 		sort.Strings(collections)
 
