@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 
 	"go.mongodb.org/mongo-driver/bson"
@@ -23,12 +24,12 @@ import (
 
 // CollectionsUsageHandler
 // https://docs.mongodb.com/manual/reference/command/top/index.html
-func CollectionsUsageHandler(s Session, _ map[string]string) (interface{}, error) {
+func CollectionsUsageHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
 	colUsage := &bson.M{}
 	err := s.DB("admin").Run(
+		ctx,
 		&bson.D{
 			{Key: "top", Value: 1},
-			{Key: "maxTimeMS", Value: s.GetMaxTimeMS()},
 		},
 		colUsage,
 	)
