@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 
 	"go.mongodb.org/mongo-driver/bson"
@@ -23,12 +24,12 @@ import (
 
 // ConnPoolStatsHandler
 // https://docs.mongodb.com/manual/reference/command/connPoolStats/#dbcmd.connPoolStats
-func ConnPoolStatsHandler(s Session, params map[string]string) (interface{}, error) {
+func ConnPoolStatsHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
 	connPoolStats := &bson.M{}
 	err := s.DB("test").Run(
+		ctx,
 		&bson.D{
 			{Key: "connPoolStats", Value: 1},
-			{Key: "maxTimeMS", Value: s.GetMaxTimeMS()},
 		},
 		connPoolStats,
 	)
