@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"errors"
 	"reflect"
 	"testing"
@@ -31,7 +32,7 @@ func Test_databasesDiscoveryHandler(t *testing.T) {
 	tests := []struct {
 		name    string
 		args    args
-		want    interface{}
+		want    any
 		wantErr error
 	}{
 		{
@@ -60,7 +61,7 @@ func Test_databasesDiscoveryHandler(t *testing.T) {
 				tt.args.s.DB(db)
 			}
 
-			got, err := DatabasesDiscoveryHandler(tt.args.s, nil)
+			got, err := DatabasesDiscoveryHandler(context.Background(), tt.args.s, nil)
 			if !errors.Is(err, tt.wantErr) {
 				t.Errorf("databasesDiscoveryHandler() error = %v, wantErr %v", err, tt.wantErr)
 
