@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 
 	"go.mongodb.org/mongo-driver/bson"
@@ -23,22 +24,21 @@ import (
 
 // ServerStatusHandler
 // https://docs.mongodb.com/manual/reference/command/serverStatus/#dbcmd.serverStatus
-func ServerStatusHandler(s Session, _ map[string]string) (interface{}, error) {
+func ServerStatusHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
 	serverStatus := &bson.M{}
-	err := s.DB("admin").Run(&bson.D{
-		{
-			Key:   "serverStatus",
-			Value: 1,
+	err := s.DB("admin").Run(ctx,
+		&bson.D{
+			{
+				Key:   "serverStatus",
+				Value: 1,
+			},
+			{
+				Key:   "recordStats",
+				Value: 0,
+			},
 		},
-		{
-			Key:   "recordStats",
-			Value: 0,
-		},
-		{
-			Key:   "maxTimeMS",
-			Value: s.GetMaxTimeMS(),
-		},
-	}, serverStatus)
+		serverStatus,
+	)
 
 	if err != nil {
 		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
