@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"errors"
 	"testing"
 
@@ -97,7 +98,7 @@ func TestVersionHandler(t *testing.T) {
 				},
 			}
 
-			got, err := VersionHandler(mockSess, nil)
+			got, err := VersionHandler(context.Background(), mockSess, nil)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf(
 					"VersionHandler() error = %v, wantErr %v", err, tt.wantErr,
