@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"errors"
 	"fmt"
 
@@ -51,7 +52,10 @@ func (conn *MockConn) DB(name string) Database {
 	return conn.dbs[name]
 }
 
-func (conn *MockConn) DatabaseNames() (names []string, err error) {
+// DatabaseNames returns mock DB names.
+func (conn *MockConn) DatabaseNames(_ context.Context) ([]string, error) {
+	names := make([]string, 0, len(conn.dbs))
+
 	for _, db := range conn.dbs {
 		if db.name == mustFail {
 			return nil, zbxerr.ErrorCannotFetchData
@@ -60,22 +64,18 @@ func (conn *MockConn) DatabaseNames() (names []string, err error) {
 		names = append(names, db.name)
 	}
 
-	return
+	return names, nil
 }
 
-func (conn *MockConn) Ping() error {
+// Ping does nothing as a mock function.
+func (*MockConn) Ping(_ context.Context) error {
 	return nil
 }
 
-func (conn *MockConn) GetMaxTimeMS() int64 {
-	return mockTimestamp
-}
-
 type MockSession interface {
 	DB(name string) Database
-	DatabaseNames() (names []string, err error)
-	GetMaxTimeMS() int64
-	Ping() error
+	DatabaseNames(ctx context.Context) ([]string, error)
+	Ping(_ context.Context) error
 }
 
 type MockMongoDatabase struct {
@@ -91,13 +91,16 @@ func (d *MockMongoDatabase) C(name string) Collection {
 
 	d.collections[name] = &MockMongoCollection{
 		name:    name,
-		queries: make(map[interface{}]*MockMongoQuery),
+		queries: make(map[any]*MockMongoQuery),
 	}
 
 	return d.collections[name]
 }
 
-func (d *MockMongoDatabase) CollectionNames() (names []string, err error) {
+// CollectionNames returns all collection names.
+func (d *MockMongoDatabase) CollectionNames(_ context.Context) ([]string, error) {
+	names := make([]string, 0, len(d.collections))
+
 	for _, col := range d.collections {
 		if col.name == mustFail {
 			return nil, errors.New("fail")
@@ -106,10 +109,11 @@ func (d *MockMongoDatabase) CollectionNames() (names []string, err error) {
 		names = append(names, col.name)
 	}
 
-	return
+	return names, nil
 }
 
-func (d *MockMongoDatabase) Run(cmd, result interface{}) error {
+// Run executed command with given mock function.
+func (d *MockMongoDatabase) Run(_ context.Context, cmd, result any) error {
 	if d.RunFunc == nil {
 		d.RunFunc = func(dbName, _ string) ([]byte, error) {
 			if dbName == mustFail {
@@ -137,10 +141,17 @@ func (d *MockMongoDatabase) Run(cmd, result interface{}) error {
 
 type MockMongoCollection struct {
 	name    string
-	queries map[interface{}]*MockMongoQuery
+	queries map[any]*MockMongoQuery
 }
 
-func (c *MockMongoCollection) Find(query interface{}, opts ...*options.FindOptions) (q Query, err error) {
+// Find retrieves documents matching query.
+//
+//nolint:ireturn,nolintlint
+func (c *MockMongoCollection) Find(
+	_ context.Context,
+	query any,
+	_ ...*options.FindOptions,
+) (Query, error) {
 	queryHash := fmt.Sprintf("%v", query)
 	if q, ok := c.queries[queryHash]; ok {
 		return q, nil
@@ -154,7 +165,14 @@ func (c *MockMongoCollection) Find(query interface{}, opts ...*options.FindOptio
 	return c.queries[queryHash], nil
 }
 
-func (c *MockMongoCollection) FindOne(query interface{}, opts ...*options.FindOneOptions) Query {
+// FindOne retrieves single document matching query.
+//
+//nolint:ireturn,nolintlint
+func (c *MockMongoCollection) FindOne(
+	_ context.Context,
+	query any,
+	_ ...*options.FindOneOptions,
+) Query {
 	queryHash := fmt.Sprintf("%v", query)
 	if q, ok := c.queries[queryHash]; ok {
 		return q
@@ -170,11 +188,11 @@ func (c *MockMongoCollection) FindOne(query interface{}, opts ...*options.FindOn
 
 type MockMongoQuery struct {
 	collection string
-	query      interface{}
+	query      any
 	DataFunc   func() ([]byte, error)
 }
 
-func (q *MockMongoQuery) retrieve(result interface{}) error {
+func (q *MockMongoQuery) retrieve(result any) error {
 	if q.DataFunc == nil {
 		return errNotFound
 	}
@@ -191,14 +209,17 @@ func (q *MockMongoQuery) retrieve(result interface{}) error {
 	return bson.Unmarshal(data, result)
 }
 
-func (q *MockMongoQuery) Count() (n int, err error) {
+// Count mock function, retrieves fake document count (always 1).
+func (*MockMongoQuery) Count(_ context.Context) (int, error) {
 	return 1, nil
 }
 
-func (q *MockMongoQuery) Get(result interface{}) error {
+// Get mock function, retrieves fake result.
+func (q *MockMongoQuery) Get(_ context.Context, result any) error {
 	return q.retrieve(result)
 }
 
-func (q *MockMongoQuery) GetSingle(result interface{}) error {
+// GetSingle mock function, retrieves fake single result.
+func (q *MockMongoQuery) GetSingle(result any) error {
 	return q.retrieve(result)
 }
