@@ -15,6 +15,8 @@
 package plugin
 
 import (
+	"context"
+
 	"golang.zabbix.com/plugin/mongodb/plugin/handlers"
 	"golang.zabbix.com/sdk/metric"
 	"golang.zabbix.com/sdk/plugin"
@@ -216,7 +218,7 @@ var metrics = metric.MetricSet{
 }
 
 // handlerFunc defines an interface must be implemented by handlers.
-type handlerFunc func(s handlers.Session, params map[string]string) (res interface{}, err error)
+type handlerFunc func(ctx context.Context, s handlers.Session, params map[string]string) (any, error)
 
 func init() {
 	err := plugin.RegisterMetrics(&Impl, Name, metrics.List()...)
